@@ -231,9 +231,9 @@ troll <- function(name = NULL,
     "abc_transmittance",
     "abc_transmittanceALS",
     "CHM",
-    "death",
-    "deathrate",
-    "death_snapshots",
+    # "death",
+    # "deathrate",
+    # "death_snapshots",
     "LAI",
     "ppfd0",
     "sdd",
